''' custom events and event subsribers '''

from pyramid.events import NewRequest, subscriber
from pyramid.renderers import render
from pyramid_mailer.message import Message

from ordr2.views import set_display_defaults


# custom events

class UserLogIn(object):
    ''' notify on user log in '''
    def __init__(self, request, user):
        self.request = request
        self.user = user


class UserNotification(object):
    ''' base class for user notifications '''

    subject = None
    template = None

    def __init__(self, request, user, data=None):
        self.request = request
        self.user = user
        self.data = data


class AccountActivation(UserNotification):
    ''' user notification for account activation '''
    subject='[ordr] Your account was activated'
    template = 'ordr2:templates/emails/activation.jinja2'


class PasswordReset(UserNotification):
    ''' user notification for password reset link '''
    subject='[ordr] Password Reset'
    template = 'ordr2:templates/emails/password_reset.jinja2'

class OrderStatusChange(UserNotification):
    ''' user notification for order status change '''
    subject='[ordr] Order Status Change'
    template = 'ordr2:templates/emails/order.jinja2'


# subsribers for events

@subscriber(UserLogIn)
def set_display_defaults_on_log_in(event):
    ''' set column display defaults at every login '''
    set_display_defaults(event.request)


@subscriber(NewRequest)
def check_display_defaults(event):
    ''' check if column display preferences are set in sesssion '''
    if event.request.user and 'display' not in event.request.session:
        set_display_defaults(event.request)


@subscriber(UserNotification)
def notify_user(event):
    ''' notify a user about an event '''
    body = render(
        event.template,
        {'user': event.user, 'data': event.data},
        event.request
        )
    message = Message(
        subject=event.subject,
        sender=event.request.registry.settings['mail.default_sender'],
        recipients=[event.user.email],
        html=body
        )
    event.request.mailer.send(message)
