''' Schemas for form input and validation '''

import colander
import deform

from deform.renderer import configure_zpt_renderer

from .helpers import (
    deferred_csrf_default,
    deferred_csrf_validator
    )

# Make Deform widgets aware of our widget template paths
configure_zpt_renderer(['ordr2:templates/deform'])


# Base Schema

class CSRFSchema(colander.Schema):
    ''' base class for schemas with csrf validation '''

    csrf_token = colander.SchemaNode(
        colander.String(),
        default=deferred_csrf_default,
        validator=deferred_csrf_validator,
        widget=deform.widget.HiddenWidget(),
        )

    @classmethod
    def as_form(cls, request, **kwargs):
        ''' returns the schema as a form '''
        url = kwargs.pop('url', None)
        if not url:
            url = request.resource_url(request.context, request.view_name)
        schema = cls().bind(request=request)
        form = deform.Form(schema, action=url, **kwargs)
        return form



class MoneyInputSchema(colander.Schema):
    ''' custom schema for structured money and currency input '''

    amount = colander.SchemaNode(
        colander.Decimal(),
        widget=deform.widget.MoneyInputWidget(
            readonly_template='textinput_disabled.pt',
            css_class='moneyinput amount'
            ),
        )
    currency = colander.SchemaNode(
        colander.String(),
        default='EUR',
        widget=deform.widget.TextInputWidget(
            readonly_template='textinput_disabled.pt',
            css_class='moneyinput currency'
            )
        )

    def __init__(self, *args, **kwargs):
        ''' define the custom schema templates '''
        if 'widget' not in kwargs:
            readonly = kwargs.pop('readonly', False)
            kwargs['widget'] = deform.widget.MappingWidget(
                category='default',
                template='money_mapping.pt',
                readonly_template='money_mapping_disabled.pt',
                item_template='money_mapping_item.pt',
                item_readonly_template='money_mapping_item_diabled.pt',
                readonly=readonly,
                )
        super().__init__(*args, **kwargs)
