''' views package

some view helpers are defined here
'''

from collections import namedtuple

# a message for session.flash()
FlashMessage = namedtuple('FlashMessage', 'message description dismissable')


def flash(request, channel, message, description='', dismissable=True):
    ''' small wrapper around request.session.flash '''
    msg = FlashMessage(message, description, dismissable)
    request.session.flash(msg, channel, allow_duplicate=False)


def update_column_display(request, section):
    ''' update the session values for which columns to display '''
    if section not in request.session['display']:
        return
    display_keys = request.session['display'][section].keys()
    display = dict.fromkeys(display_keys, False)
    for column in request.POST.values():
        if column in display:
            display[column] = True
    request.session['display'][section] = display


def set_display_defaults(request):
    ''' sets the coulumn display default  '''
    defaults = {
        'users': {
            'first': True,
            'last': True,
            'email': True,
            },
        'orders': {
            'account': False,
            'cas': True,
            'catalog': False,
            'vendor': True,
            'price': False,
            'amount': False,
            'total': True,
            }
        }
    request.session['display'] = defaults


def includeme(config):
    ''' adding request helpers and static views

    Activate this setup using ``config.include('ordr2.views')``.
    '''
    config.add_request_method(flash, 'flash')

    settings = config.get_settings()
    age = int(settings.get('static_views.cache_max_age', 3600))

    config.add_static_view('static', 'ordr2:static', cache_max_age=age)
    config.add_static_view('deform', 'deform:static', cache_max_age=age)

