#!/usr/bin/env python
# -*- coding: utf-8 -*-

''' The setup script. '''

from setuptools import setup, find_packages

with open('README.rst') as readme_file:
    readme = readme_file.read()

with open('HISTORY.rst') as history_file:
    history = history_file.read()

requirements = [
    'pyramid',
    'pyramid_jinja2',
    'pyramid_debugtoolbar',
    'pyramid_tm',
    'pyramid_mailer',
    'bcrypt',
    'deform',
    'PyYAML',
    'SQLAlchemy',
    'tqdm',
    'transaction',
    'waitress',
    'XlsxWriter',
    'zope.sqlalchemy',
]

setup_requirements = [
    'pytest-runner',
    # TODO(holgi): put setup requirements (distutils extensions, etc.) here
]

test_requirements = [
    'WebTest >= 1.3.1',  # py3 compat
    'pytest',
    'pytest-cov',
    # TODO: put package test requirements here
]

setup(
    name='ordr2',

    version='0.1.4',

    description='CPI Ordering System',
    long_description=readme + '\n\n' + history,

    author='Holger Frey',
    author_email='frey@imtek.de',
    url='https://github.com/holgi/ordr2',

    packages=find_packages(include=['ordr2']),

    include_package_data=True,
    install_requires=requirements,
    license='BSD license',

    zip_safe=False,

    keywords='ordr2 web pyramid pylons',

    # see https://pypi.python.org/pypi?%3Aaction=list_classifiers
    classifiers=[
        'Development Status :: 2 - Pre-Alpha',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: BSD License',
        'Natural Language :: English',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Framework :: Pyramid',
        'Topic :: Internet :: WWW/HTTP',
        'Topic :: Internet :: WWW/HTTP :: WSGI :: Application',
    ],

    test_suite='tests',
    tests_require=test_requirements,

    setup_requires=setup_requirements,
    entry_points={
        'paste.app_factory': [
            'main = ordr2:main',
        ],
        'console_scripts': [
            'initialize_ordr2_db = ordr2.scripts.initializedb:main',
        ],
    },
)
